#!/bin/sh
#
# pine-mutt.sh version 1
# by Daniel Eisenbud <eisenbud@cs.swarthmore.edu>
#
# Usage: sh pine-mutt.sh <filename>
# where filename is a pine aliases file will output a mutt aliases file
# on standard output.
#
# Limitations: assumes that all alias names start with an alphanumeric
# character.  If this isn't true for you, just change the regex in the
# third line of the first awk script.
#
# This seems to work well for versions of pine
# around 3.94 or 3.95.  It may well work for others, but YMMV.
#
# By default it turns pine's fcc field into a
# commented-out save-hook.  If you want, you can either remove the 
# hash mark on the second-to-last line to have the save-hooks by
# default, or you can put a hash mark at the very beginning of the line
# to eliminate their production altogether.
#
cat $1 | awk '
BEGIN { FS = "\t" }
/^ / { printf "%s", $0 }
/^[A-Za-z0-9]/ { printf "\n%s",  $0 }
' | awk '
BEGIN { FS = "\t" }
length($2)>0 {split ($2,realname,",");
		namestring="("realname[2] " "  realname[1] " )" }
$3 ~   /^\(.*\)$/ {address=substr($3,2,length($3)-2)}
$3 !~  /^\(.*\)$/ {address=$3}
length($5)>0 {comment="#" $5}
length($5)==0 {comment=""}
length > 0 {printf "alias %s\t%s %s\t%s\n",$1,address,namestring,comment}
length($4)>0 {printf "#save-hook %s =%s\n", $1, $4}
'
